package org.apache.commons.lang3.builder;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.util.Collection;
import java.util.Map;
import java.util.Objects;
import org.apache.commons.lang3.StringEscapeUtils;
import org.apache.commons.lang3.builder.ToStringStyle;

final class JsonToStringStyle extends ToStringStyle {
  private static final long serialVersionUID = 1L;
  
  private static final String FIELD_NAME_QUOTE = "\"";
  
  JsonToStringStyle() {
    setUseClassName(false);
    setUseIdentityHashCode(false);
    setContentStart("{");
    setContentEnd("}");
    setArrayStart("[");
    setArrayEnd("]");
    setFieldSeparator(",");
    setFieldNameValueSeparator(":");
    setNullText("null");
    setSummaryObjectStartText("\"<");
    setSummaryObjectEndText(">\"");
    setSizeStartText("\"<size=");
    setSizeEndText(">\"");
  }
  
  public void append(StringBuffer buffer, String fieldName, Object[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, long[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, int[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, short[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, byte[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, char[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, double[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, float[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, boolean[] array, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, array, fullDetail);
  }
  
  public void append(StringBuffer buffer, String fieldName, Object value, Boolean fullDetail) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    if (!isFullDetail(fullDetail))
      throw new UnsupportedOperationException("FullDetail must be true when using JsonToStringStyle"); 
    super.append(buffer, fieldName, value, fullDetail);
  }
  
  protected void appendDetail(StringBuffer buffer, String fieldName, char value) {
    appendValueAsString(buffer, String.valueOf(value));
  }
  
  protected void appendDetail(StringBuffer buffer, String fieldName, Object value) {
    if (value == null) {
      appendNullText(buffer, fieldName);
      return;
    } 
    if (value instanceof String || value instanceof Character) {
      appendValueAsString(buffer, value.toString());
      return;
    } 
    if (value instanceof Number || value instanceof Boolean) {
      buffer.append(value);
      return;
    } 
    String valueAsString = value.toString();
    if (isJsonObject(valueAsString) || isJsonArray(valueAsString)) {
      buffer.append(value);
      return;
    } 
    appendDetail(buffer, fieldName, valueAsString);
  }
  
  protected void appendDetail(StringBuffer buffer, String fieldName, Collection<?> coll) {
    if (coll != null && !coll.isEmpty()) {
      buffer.append(getArrayStart());
      int i = 0;
      for (Object item : coll)
        appendDetail(buffer, fieldName, i++, item); 
      buffer.append(getArrayEnd());
      return;
    } 
    buffer.append(coll);
  }
  
  protected void appendDetail(StringBuffer buffer, String fieldName, Map<?, ?> map) {
    if (map != null && !map.isEmpty()) {
      buffer.append(getContentStart());
      boolean firstItem = true;
      for (Map.Entry<?, ?> entry : map.entrySet()) {
        String keyStr = Objects.toString(entry.getKey(), null);
        if (keyStr != null) {
          if (firstItem) {
            firstItem = false;
          } else {
            appendFieldEnd(buffer, keyStr);
          } 
          appendFieldStart(buffer, keyStr);
          Object value = entry.getValue();
          if (value == null) {
            appendNullText(buffer, keyStr);
            continue;
          } 
          appendInternal(buffer, keyStr, value, true);
        } 
      } 
      buffer.append(getContentEnd());
      return;
    } 
    buffer.append(map);
  }
  
  private boolean isJsonArray(String valueAsString) {
    return (valueAsString.startsWith(getArrayStart()) && valueAsString
      .endsWith(getArrayEnd()));
  }
  
  private boolean isJsonObject(String valueAsString) {
    return (valueAsString.startsWith(getContentStart()) && valueAsString
      .endsWith(getContentEnd()));
  }
  
  private void appendValueAsString(StringBuffer buffer, String value) {
    buffer.append('"').append(StringEscapeUtils.escapeJson(value)).append('"');
  }
  
  protected void appendFieldStart(StringBuffer buffer, String fieldName) {
    if (fieldName == null)
      throw new UnsupportedOperationException("Field names are mandatory when using JsonToStringStyle"); 
    super.appendFieldStart(buffer, "\"" + StringEscapeUtils.escapeJson(fieldName) + "\"");
  }
  
  private Object readResolve() {
    return JSON_STYLE;
  }
}
